==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AModBinop.h <==
// public final class soot.jimple.parser.node.AModBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b73276a4fea7fbf soot_jimple_parser_node_AModBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AModBinop_H_
#define _JC_soot_jimple_parser_node_AModBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMod$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AModBinop$sub_refs	_jc_soot_jimple_parser_node_AModBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AModBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$refs	_jc_soot_jimple_parser_node_AModBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$nonrefs	_jc_soot_jimple_parser_node_AModBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$object	_jc_soot_jimple_parser_node_AModBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AModBinop$vmethods	_jc_soot_jimple_parser_node_AModBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AModBinop$vtable	_jc_soot_jimple_parser_node_AModBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AModBinop$vtype	_jc_soot_jimple_parser_node_AModBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AModBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
extern void _jc_soot_jimple_parser_node_AModBinop$method$_init$4c0a873db809475d(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AModBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AModBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
extern struct _jc_soot_jimple_parser_node_TMod$object *_jc_soot_jimple_parser_node_AModBinop$method$getMod$a49290759923de02(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
extern void _jc_soot_jimple_parser_node_AModBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AModBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AModBinop$method$setMod$abe56540f5ab5bc5(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AModBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$getMod$a49290759923de02;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$setMod$abe56540f5ab5bc5;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AModBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
	struct _jc_soot_jimple_parser_node_TMod$object	*(*getMod$a49290759923de02)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setMod$abe56540f5ab5bc5)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AModBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AModBinop$vmethods	soot_jimple_parser_node_AModBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AModBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AModBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AModBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMod$object	*__5fmod__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AModBinop$refs {
    _jc_soot_jimple_parser_node_AModBinop$sub_refs	soot_jimple_parser_node_AModBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AModBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs	soot_jimple_parser_node_AModBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AModBinop$object {
	_jc_soot_jimple_parser_node_AModBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AModBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AModBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AModBinop$vtype _jc_soot_jimple_parser_node_AModBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AModBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AModBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AModBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AModBinop.h <==
// public final class soot.jimple.parser.node.AModBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b73276a4fea7fbf soot_jimple_parser_node_AModBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AModBinop_H_
#define _JC_soot_jimple_parser_node_AModBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TMod$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AModBinop$sub_refs	_jc_soot_jimple_parser_node_AModBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AModBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$refs	_jc_soot_jimple_parser_node_AModBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$nonrefs	_jc_soot_jimple_parser_node_AModBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AModBinop$object	_jc_soot_jimple_parser_node_AModBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AModBinop$vmethods	_jc_soot_jimple_parser_node_AModBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AModBinop$vtable	_jc_soot_jimple_parser_node_AModBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AModBinop$vtype	_jc_soot_jimple_parser_node_AModBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AModBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AModBinop$method$_init$4c0a873db809475d(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AModBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AModBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TMod$object *_jc_soot_jimple_parser_node_AModBinop$method$getMod$a49290759923de02(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AModBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AModBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AModBinop$method$setMod$abe56540f5ab5bc5(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AModBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$getMod$a49290759923de02;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$setMod$abe56540f5ab5bc5;
extern _jc_method _jc_soot_jimple_parser_node_AModBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AModBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TMod$object	*(*getMod$a49290759923de02)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setMod$abe56540f5ab5bc5)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *, struct _jc_soot_jimple_parser_node_TMod$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AModBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AModBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AModBinop$vmethods	soot_jimple_parser_node_AModBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AModBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AModBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AModBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TMod$object	*__5fmod__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AModBinop$refs {
    _jc_soot_jimple_parser_node_AModBinop$sub_refs	soot_jimple_parser_node_AModBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AModBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AModBinop$sub_nonrefs	soot_jimple_parser_node_AModBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AModBinop$object {
	_jc_soot_jimple_parser_node_AModBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AModBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AModBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AModBinop$vtype _jc_soot_jimple_parser_node_AModBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AModBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AModBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AModBinop_H_ */
